#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2007  Donald N. Allingham
# Copyright (C) 2007-2008  Brian G. Matherly
# Copyright (C) 2008  Jerome Rapinat
# Copyright (C) 2008  Benny Malengier
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, see <https://www.gnu.org/licenses/>.
#
# gen.filters.rules/_HasNoteBase.py

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ...const import GRAMPS_LOCALE as glocale

_ = glocale.translation.gettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from . import Rule


# -------------------------------------------------------------------------
#
# Typing modules
#
# -------------------------------------------------------------------------
from ...lib.notebase import NoteBase
from ...db import Database


# -------------------------------------------------------------------------
# "Objects having notes"
# -------------------------------------------------------------------------
class HasNoteBase(Rule):
    """Objects having notes"""

    labels = [_("Number of instances:"), _("Number must be:")]
    name = "Object with notes"
    description = "Matches objects that have a certain number of notes"
    category = _("General filters")

    def __init__(self, arg, use_regex=False, use_case=False):
        # Upgrade from pre 3.1 HasNote filter, use defaults that correspond
        # Previous filter had 0 arguments
        if len(arg) == 0:
            Rule.__init__(self, ["0", "greater than"], use_regex, use_case)
        else:
            Rule.__init__(self, arg, use_regex, use_case)

    def prepare(self, db: Database, user):
        # things we want to do just once, not for every handle
        if self.list[1] == "less than":
            self.count_type = 0
        elif self.list[1] == "greater than":
            self.count_type = 2
        else:
            self.count_type = 1  # "equal to"

        self.userSelectedCount = int(self.list[0])

    def apply_to_one(self, db: Database, obj: NoteBase) -> bool:
        count = len(obj.note_list)
        if self.count_type == 0:  # "less than"
            return count < self.userSelectedCount
        elif self.count_type == 2:  # "greater than"
            return count > self.userSelectedCount
        # "equal to"
        return count == self.userSelectedCount



#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2003-2006  Donald N. Allingham
#               2009       Gary Burton
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, see <https://www.gnu.org/licenses/>.
#

# -------------------------------------------------------------------------
#
# internationalization
#
# -------------------------------------------------------------------------

# -------------------------------------------------------------------------
#
# gramps modules
#
# -------------------------------------------------------------------------
from gramps.gen.const import GRAMPS_LOCALE as glocale

_ = glocale.translation.sgettext
from ..views.treemodels import FamilyModel
from .baseselector import BaseSelector
from gramps.gen.const import URL_MANUAL_PAGE

# -------------------------------------------------------------------------
#
# Constants
#
# -------------------------------------------------------------------------


# -------------------------------------------------------------------------
#
# SelectFamily
#
# -------------------------------------------------------------------------
class SelectFamily(BaseSelector):
    def _local_init(self):
        """
        Perform local initialisation for this class
        """
        self.setup_configs("interface.family-sel", 600, 450)

    def get_window_title(self):
        return _("Select Family")

    def get_model_class(self):
        return FamilyModel

    def get_column_titles(self):
        return [
            (_("ID"), 75, BaseSelector.TEXT, 0),
            (_("Father"), 200, BaseSelector.TEXT, 1),
            (_("Mother"), 200, BaseSelector.TEXT, 2),
            (_("Last Change"), 150, BaseSelector.TEXT, 7),
        ]

    def get_from_handle_func(self):
        return self.db.get_family_from_handle

    def get_config_name(self):
        return __name__

    WIKI_HELP_PAGE = "%s_-_Categories" % URL_MANUAL_PAGE
    WIKI_HELP_SEC = _("Select_Family_selector", "manual")



#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2000-2007  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, see <https://www.gnu.org/licenses/>.
#

"""
Provide the different family reference types.
"""

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from ..config import config
from ..const import GRAMPS_LOCALE as glocale
from .grampstype import GrampsType

_ = glocale.translation.gettext


# -------------------------------------------------------------------------
#
# FamilyRelType
#
# -------------------------------------------------------------------------
class FamilyRelType(GrampsType):
    """
    Class for type of relationship between two partners forming the family.
    """

    MARRIED = 0
    UNMARRIED = 1
    CIVIL_UNION = 2
    UNKNOWN = 3
    CUSTOM = 4

    _CUSTOM = CUSTOM
    _DEFAULT = MARRIED

    _DATAMAP = [
        (MARRIED, _("Married"), "Married"),
        (UNMARRIED, _("Unmarried"), "Unmarried"),
        (CIVIL_UNION, _("Civil Union"), "Civil Union"),
        (UNKNOWN, _("Unknown"), "Unknown"),
        (CUSTOM, _("Custom"), "Custom"),
    ]

    def __init__(self, value=None):
        if value is None:
            value = config.get("preferences.family-relation-type")
        GrampsType.__init__(self, value)
